@@ -42,6 +42,7 @@ from msserviceprofiler.modelevalstate.inference.common import HistInfo, model_op
 from msserviceprofiler.modelevalstate.inference.constant import OpAlgorithm
 from msserviceprofiler.modelevalstate.model.xgb_state_model import StateXgbModel
 from msserviceprofiler.modelevalstate.train.state_param import StateParam
+from msserviceprofiler.modelevalstate.inference.utils import save_dataframe_to_csv
 
 
 @dataclass
@@ -130,7 +131,7 @@ class PretrainModel:
         logger.info("start train")
         self.dataset.construct_data(lines_data, plt_data=self.plt_data, middle_save_path=middle_save_path)
         rmse = self.model.train(self.dataset, middle_save_path=middle_save_path)
-        logger.info(f"rmse {rmse}")
+        logger.debug(f"rmse {rmse}")
 
         self.rmse.append(rmse)
 
@@ -146,11 +147,14 @@ class PretrainModel:
         # 使用模型进行预测
         target_data = []
         for _, row in features.iterrows():
-            _predict = self.model.predict((row,))[0]
-            stage = self.get_stage_after_preprocess(row, self.dataset.custom_encoder)
-            _cur_node = NodeInfo(stage, row.batch_size)
-            setattr(_cur_node, self.state_param.predict_field, _predict)
-            target_data.append(_cur_node)
+            try:
+                _predict = self.model.predict((row,))[0]
+                stage = self.get_stage_after_preprocess(row, self.dataset.custom_encoder)
+                _cur_node = NodeInfo(stage, row.batch_size)
+                setattr(_cur_node, self.state_param.predict_field, _predict)
+                target_data.append(_cur_node)
+            except Exception as e:
+                logger.error(f"get_nodes_with_model_predict时出错：{e}")  
         return tuple(target_data)
 
     def predict_and_plot(self, features: DataFrame, labels: DataFrame, predict_field: str, save_path: Optional[Path]):
@@ -182,15 +186,15 @@ class PretrainModel:
         return all_up, all_ud
 
     def predict_and_plot_with_speed(self, features: DataFrame, labels: DataFrame, save_path: Optional[Path]):
-        logger.info("predict test data.")
+        logger.debug("predict test data.")
         _predicts = self.model.predict(features.values)
         _origin_data = labels
         r2 = r2_score(labels, _predicts)
         self.r2.append(r2)
-        logger.info(f"r2: {r2}")
+        logger.debug(f"r2: {r2}")
         mape = mean_absolute_percentage_error(labels, _predicts)
         self.mape.append(mape)
-        logger.info(f"mape: {mape}")
+        logger.debug(f"mape: {mape}")
         _predict_df = pd.DataFrame({"batch_stage": self.dataset.load_data["batch_stage"],
                                     "batch_size": self.dataset.load_data["batch_size"],
                                     "predict": _predicts})
@@ -230,7 +234,7 @@ class PretrainModel:
 
     def bak_model(self, increment_stage: str = "base"):
         _bak_dir = self.state_param.bak_dir.joinpath(increment_stage)
-        _bak_dir.mkdir(parents=True, exist_ok=True)
+        _bak_dir.mkdir(parents=True, exist_ok=True, mode=0o750)
         shutil.copy(self.state_param.xgb_model_save_model_path,
                     _bak_dir.joinpath(self.state_param.xgb_model_save_model_path.name))
 
@@ -245,39 +249,6 @@ class PretrainModel:
             plt.show()
 
 
-class ReqDecodePretrainModel(PretrainModel):
-    def train(self, lines_data: Optional[DataFrame] = None,
-              middle_save_path: Optional[Path] = None):
-        self.dataset.construct_data(lines_data, plt_data=self.plt_data, middle_save_path=middle_save_path)
-        rmse = self.model.train(self.dataset, middle_save_path=middle_save_path)
-        self.rmse.append(rmse)
-
-    def get_nodes_with_model_predict(self, features: DataFrame):
-        # 使用模型进行预测
-        target_data = []
-        for _, row in features.iterrows():
-            _predict = ceil(self.model.predict((row,))[0])
-            target_data.append(_predict)
-        return tuple(target_data)
-
-    def predict_and_plot(self, features: DataFrame, labels: DataFrame, predict_field: str, save_path: Optional[Path]):
-        origin_data = labels.values
-        data = self.get_nodes_with_model_predict(features)
-
-        r2 = r2_score(origin_data, data)
-        self.r2.append(r2)
-        mape = mean_absolute_percentage_error(origin_data,
-                                              data)
-        self.mape.append(mape)
-        AnalysisState.plot_pred_and_real(data, origin_data, save_path)
-        ax = sns.lineplot(pd.DataFrame({"predict": data, "real": origin_data}))
-        if save_path:
-            plt.savefig(save_path.joinpath("decode_num_predict_real.png"))
-        else:
-            plt.show()
-        plt.close()
-
-
 class TrainVersion1:
     @staticmethod 
     def simple_train(file_paths: List[Path], sp: StateParam, pm: PretrainModel):
@@ -294,48 +265,21 @@ class TrainVersion1:
         line_data = line_data.applymap(replace_none)
         line_data = line_data.dropna()
         train_data, test_data = train_test_split(line_data, test_size=0.1, shuffle=True)
-        logger.info(f"train data shape {train_data.shape}")
+        logger.debug(f"train data shape {train_data.shape}")
         sp.comments = f"input files: {file_paths} \n"
         save_path = sp.step_dir.joinpath("base")
-        save_path.mkdir(parents=True, exist_ok=True)
+        save_path.mkdir(parents=True, exist_ok=True, mode=0o750)
         pm.train(train_data.reset_index(drop=True), middle_save_path=save_path)
         sp.comments += f'feature shape {pm.dataset.features.shape}\n'
         sp.comments += (f"data shuffle: True, \n train case: {pm.dataset.train_x.shape}, "
                         f"validate case: {pm.dataset.test_x.shape}, predict case: {test_data.shape} \n")
         pm.bak_model()
-        logger.info("test data {test_data.shape}")
+        logger.debug("test data {test_data.shape}")
         save_path = sp.step_dir.joinpath("1")
-        save_path.mkdir(parents=True, exist_ok=True)
+        save_path.mkdir(parents=True, exist_ok=True, mode=0o750)
         pm.predict(test_data.reset_index(drop=True), save_path)
         logger.info("finished train")
 
-    @staticmethod
-    def increment_train(fl: FileReader, sp: StateParam, pm: PretrainModel):
-        # 增量训练
-        count = 1
-        while True:
-            try:
-                # 1000行
-                lines = fl.read_lines()
-                save_path = sp.step_dir.joinpath(str(count))
-                save_path.mkdir(parents=True, exist_ok=True)
-                pm.predict(lines, save_path=save_path)
-                pm.partial_train(lines, middle_save_path=save_path)
-                count += 1
-            except StopIteration:
-                break
-        pm.bak_model(increment_stage="finished")
-
-    @staticmethod
-    def full_train(fl: FileReader, sp: StateParam, pm: PretrainModel):
-        # 全量训练
-        train_data = fl.read_lines()
-        save_path = sp.step_dir.joinpath("base")
-        save_path.mkdir(parents=True, exist_ok=True)
-        pm.train(train_data, middle_save_path=save_path)
-        pm.bak_model()
-
-
 
 parser = argparse.ArgumentParser(prog="Train Model.")
 parser.add_argument("-i", "--input", default=None, type=Path, required=True)
@@ -355,7 +299,7 @@ def pretrain(input_path, output_path):
     # 创建输出目录
     output = Path(output_path).expanduser().resolve()
     if not output.exists:
-        output.mkdir(parents=True)
+        output.mkdir(parents=True, mode=0o750)
     # 运行模型训练
     sp = StateParam(
         base_path=output,
@@ -388,10 +332,8 @@ def pretrain(input_path, output_path):
     TrainVersion1.simple_train(train_files, sp, pm)
     train_data = dataset.features.copy(deep=False)
     train_data["label"] = dataset.labels
-    _train_file = output.joinpath("cache/train_data.csv")
-    if not _train_file.parent.exists():
-        _train_file.parent.mkdir(parents=True)
-    train_data.to_csv(output.joinpath("cache/train_data.csv"), index=False)
+    _train_dir = output.joinpath("cache")
+    save_dataframe_to_csv(train_data, _train_dir, "train_data.csv")
 
 
 def main(args):
