@@ -19,9 +19,11 @@ import re
 import subprocess
 
 from msserviceprofiler.msservice_advisor.profiling_analyze.register import register_analyze, answer, GLOBAL_DATA
-from msserviceprofiler.msservice_advisor.profiling_analyze.utils import logger, SUGGESTION_TYPES, BYTES_TO_GB
-from msserviceprofiler.msservice_advisor.profiling_analyze.utils import vaild_readable_directory, vaild_readable_file
+from msserviceprofiler.msservice_advisor.profiling_analyze.utils import (
+    logger, SUGGESTION_TYPES, BYTES_TO_GB, MAX_DEVICE_ID_LIST_LENGTH
+)
 from msserviceprofiler.msservice_advisor.profiling_analyze.utils import get_directory_size, read_csv_or_json
+from msserviceprofiler.msguard import validate_params, Rule
 
 
 def get_benchmark_token_num(benchmark, info_name):
@@ -92,8 +94,8 @@ def extract_server_config_params(server_config, output_token_num, tp=1):
     output_token_num, cache_block_sizes = get_schedule_config_info(backend_config, output_token_num)
 
     npu_device_ids = backend_config.get('npuDeviceIds', [[]])[0]
-    if not npu_device_ids or len(npu_device_ids) == 0:
-        raise Exception("mindie-server config.json missing 'npuDeviceIds'.")
+    if not npu_device_ids or len(npu_device_ids) == 0 or len(npu_device_ids) >= MAX_DEVICE_ID_LIST_LENGTH:
+        raise Exception("mindie-server config.json missing 'npuDeviceIds' or it's invaild.")
     logger.info(f"npu_device_ids: {npu_device_ids}")
 
     model_configs = backend_config.get('ModelDeployConfig', {}).get('ModelConfig', [[]])[0]
@@ -110,19 +112,14 @@ def extract_server_config_params(server_config, output_token_num, tp=1):
     )
 
 
+@validate_params({'model_weight_path': Rule.input_dir_traverse})
 def extract_model_config_params(model_weight_path):
     """
         获取模型参数信息，及模型权重文件总大小
     """
-    # check model weight directory
-    vaild_readable_directory(model_weight_path)
-
-    # check model config.json
-    model_config_file = os.path.join(model_weight_path, "config.json")
-    model_config_file = vaild_readable_file(model_config_file)
-    logger.info(f"model config path: {model_config_file}")
-
     # get model config.json
+    model_config_file = os.path.join(model_weight_path, "config.json")
+    logger.info(f"model config path: {model_config_file}")
     model_params = read_csv_or_json(model_config_file)
 
     # caculate model weight size
@@ -330,7 +327,7 @@ def cal_total_block_num(npu_mem_size, server_params, model_params):
             raise ValueError(f'Invaild num_attention_heads.')
         attention_head_size = hidden_size / num_attention_heads / tp
         attention_size = attention_head_size * num_key_value_heads
-    logger.debug(f"attention_size:{attention_size}")
+    logger.debug(f"attention_size: {attention_size}")
 
     denominator = num_hidden_layers * cache_block_sizes * attention_size * torch_dtype_size * 2
     if denominator <= 0:
@@ -400,30 +397,30 @@ def write_to_answer(min_batch, max_batch, avg_batch):
 
 
 @register_analyze()
-def find_max_batch_size_range(server_config, benchmark, output_log, input_params):
+def find_max_batch_size_range(server_config, benchmark, input_params):
     # get input token number and average output token num
     input_token_num, avg_token_num = extract_token_num(benchmark, input_params)
 
     if not server_config:
-        logger.warning(f"service_config_path is required calculating model weight size and others. Skipping now")
+        logger.warning(f"service_config_path is required calculating model weight size and others. Skipping now.")
         return
 
     # get server info from server config.json
     try:
         server_params = extract_server_config_params(server_config, input_params.output_token_num, input_params.tp)
     except Exception as e:
-        logger.warning(f"Skip npu memory analyze due to {e}, please check mindie-server config content.")
+        logger.warning(f"Extract server config params failed due to {e}. Skipping now.")
         return
     
     if "model_weight_path" not in server_params:
-        logger.warning(f"model_weight_path not found in content of service_config_path. Skipping now")
+        logger.warning(f"model_weight_path not found in service config.json. Skipping now.")
         return
     
     # get model info from model config.json
     try:
         model_params, model_weight_size = extract_model_config_params(server_params["model_weight_path"])
     except Exception as e:
-        logger.warning(f"Skip npu memory analyze due to invaild model weight. {e}")
+        logger.warning(f"Invaild model weight due to {e}. Skipping now.")
         return
 
     # caculate npu memory
@@ -432,7 +429,7 @@ def find_max_batch_size_range(server_config, benchmark, output_log, input_params
         total_block_num = cal_total_block_num(npu_mem_size, server_params, model_params)
         logger.debug(f"total_block_num:{total_block_num}")
     except Exception as e:
-        logger.warning(f"Skip npu memory analyze due to npu memory calculation failed. {e}")
+        logger.warning(f"Npu memory calculation failed due to {e}. Skipping now.")
         return
     
     # caculate block numbers
